==> freerdp3_3.17.2+dfsg.orig.tar.xz: freerdp-3.17.2/server/shadow/shadow_channels.c <==
/**
 * FreeRDP: A Remote Desktop Protocol Implementation
 *
 * Copyright 2014 Marc-Andre Moreau <marcandre.moreau@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <freerdp/config.h>

#include "shadow.h"

#include "shadow_channels.h"

UINT shadow_client_channels_post_connect(rdpShadowClient* client)
{
	if (WTSVirtualChannelManagerIsChannelJoined(client->vcm, ENCOMSP_SVC_CHANNEL_NAME))
	{
		shadow_client_encomsp_init(client);
	}

	if (WTSVirtualChannelManagerIsChannelJoined(client->vcm, REMDESK_SVC_CHANNEL_NAME))
	{
		shadow_client_remdesk_init(client);
	}

	if (WTSVirtualChannelManagerIsChannelJoined(client->vcm, RDPSND_CHANNEL_NAME))
	{
		shadow_client_rdpsnd_init(client);
	}

	shadow_client_audin_init(client);

	shadow_client_rdpgfx_init(client);

	return CHANNEL_RC_OK;
}

void shadow_client_channels_free(rdpShadowClient* client)
{
	shadow_client_rdpgfx_uninit(client);
	shadow_client_audin_uninit(client);
	shadow_client_rdpsnd_uninit(client);
	shadow_client_remdesk_uninit(client);
	shadow_client_encomsp_uninit(client);
}

==> freerdp3_3.23.0+dfsg.orig.tar.xz: freerdp-3.23.0/server/shadow/shadow_channels.c <==
/**
 * FreeRDP: A Remote Desktop Protocol Implementation
 *
 * Copyright 2014 Marc-Andre Moreau <marcandre.moreau@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <freerdp/config.h>

#include "shadow.h"

#include "shadow_channels.h"

UINT shadow_client_channels_post_connect(rdpShadowClient* client)
{
	if (WTSVirtualChannelManagerIsChannelJoined(client->vcm, ENCOMSP_SVC_CHANNEL_NAME))
	{
		if (shadow_client_encomsp_init(client) < 0)
			return ERROR_NOT_READY;
	}

	if (WTSVirtualChannelManagerIsChannelJoined(client->vcm, REMDESK_SVC_CHANNEL_NAME))
	{
		if (shadow_client_remdesk_init(client) < 0)
			return ERROR_NOT_READY;
	}

	if (WTSVirtualChannelManagerIsChannelJoined(client->vcm, RDPSND_CHANNEL_NAME))
	{
		if (shadow_client_rdpsnd_init(client) < 0)
			return ERROR_NOT_READY;
	}

	if (!shadow_client_audin_init(client))
		return ERROR_NOT_READY;

	if (shadow_client_rdpgfx_init(client) < 0)
		return ERROR_NOT_READY;

	return CHANNEL_RC_OK;
}

void shadow_client_channels_free(rdpShadowClient* client)
{
	shadow_client_rdpgfx_uninit(client);
	shadow_client_audin_uninit(client);
	shadow_client_rdpsnd_uninit(client);
	shadow_client_remdesk_uninit(client);
	shadow_client_encomsp_uninit(client);
}
